package com.example.springdemo.controller;

import com.example.springdemo.entities.Users;
import com.example.springdemo.entities.password.UsersPassword;
import com.example.springdemo.service.UsersService;
import com.example.springdemo.utils.RoleVerificationAnnotation;
import jakarta.annotation.Resource;
import lombok.Data;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

@RestController
@RequestMapping("/users")
public class UsersController {

    @Resource
    private UsersService usersService;

    //添加新用户
    @RoleVerificationAnnotation(UserIDList = {1})
    @PostMapping("/add")
    public Users addUsers(@RequestBody wrapperUserAndPassword wrapperUserAndPassword) {
        return usersService.addUser(
                wrapperUserAndPassword.user,
                wrapperUserAndPassword.userPassword);
    }

    @Data
    public static class wrapperUserAndPassword {
        public Users user;
        public UsersPassword userPassword;
    }

    //通过ID删除用户
    @RoleVerificationAnnotation(UserIDList = {1})
    @DeleteMapping("/delete/id")
    public void deleteUserById(@RequestParam(name = "id") Long userId) {
        usersService.deleteUserById(userId);
    }

    //通过姓名删除用户
    @RoleVerificationAnnotation(UserIDList = {1})
    @DeleteMapping("/delete/name")
    public void deleteUserByName(@RequestParam(name = "name") String name) {
        usersService.deleteUserByName(name);
    }

    //更新用户信息
    @RoleVerificationAnnotation(RoleIDList = {1, 3}, UserIDList = {1})
    @PutMapping("/update/info")
    public Users updateUser(@RequestBody Users user) {
        return usersService.updateUser(user);
    }

    //查找全部用户
    @RoleVerificationAnnotation(UserIDList = {1})
    @GetMapping("/find/all")
    public List<Users> getUsers() {
        return usersService.findAllUsers();
    }

    //根据姓名查找用户
    @RoleVerificationAnnotation(UserIDList = {1})
    @GetMapping("/find/name")
    public Optional<Users> getUsersByName(@RequestParam(name = "name") String name) {
        return usersService.findByName(name);
    }

    //根据ID查找用户
    @RoleVerificationAnnotation(UserIDList = {1})
    @GetMapping("/find/id")
    public Optional<Users> getUsersById(@RequestParam(name = "id") Long userId) {
        return usersService.findById(userId);
    }

    //更新用户密码
    @RoleVerificationAnnotation(RoleIDList = {1, 3}, UserIDList = {1})
    @PutMapping("/update/password")
    public int updatePassword(@RequestParam(name = "password") String password,
                              @RequestParam(name = "userId") Long userId) {
        return usersService.updateUserPasswordById(password, userId);
    }
}
